/** \mainpage APCI-2032 API functions documentation
* \section intro_sec Introduction
* See the modules chapter to view the functions \n
*/

 /** @file PCI2032.H
 * Header file of the APCI-2032 
 * 
 * 
 *  @author C. Guinot
 *  @date 14.04.2008
 *  
 *  
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2004,2005  ADDI-DATA GmbH for the source code of this module.
 *       
 *       ADDI-DATA GmbH 
 *       Dieselstrasse 3 
 *       D-77833 Ottersweier 
 *       Tel: +19(0)7223/9493-0 
 *       Fax: +49(0)7223/9493-92 
 *       http://www.addi-data-com 
 *       info@addi-data.com 
 *       
 * @endverbatim   
 */

#include <stdio.H>
#include <dos.H>
#include <windows.h>
#include <winioctl.h>
#include <io.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <math.h>

#include "define.h"

#ifdef __cplusplus
	extern "C" {
#endif

/** \defgroup PCI2032 xPCI-2032 functions 
 * @{ 
 */ 
/* @} */ 

/** \addtogroup General xPCI-2032 general functions 
* \ingroup PCI2032 
 * @{ 
 * 
 */ 

/**  Return the number of xPCI-2032 board found (pb_NbrOfBoards)
*                                    
*                                                                             
* @param[out] pb_NbrOfBoards Return the number of board found                  
* @return    > 0 : Warning \n                                                 
*              0 : No Error                                                   */
_INT_ i_PCI2032_GetNumberOfBoards (PBYTE pb_NbrOfBoards);

/** Get device information of the board.
*                                                                   
* @param[in] b_BoardIndex : Index of the board         
* @param[in] dw_IdentifierStringSize : size of the identifier parameter
* @param[out] pc_Identifier: Identifier of the board
* @param[out] pdw_UINumber : This number is typically a user-perceived slot number, such as a number printed next to the slot on the board, or some other number that makes locating the physical device easier for the user. If the device is on a bus that has no UI number convention, or if the bus driver for the device cannot determine the UI number, this value is 0xFFFFFFFF.
* @param[out] pdw_DeviceNumber : Device number.
* @param[out] pdw_BusNumber : Bus number.
* @param[out] pdw_BaseAddress0 : Base address 0 of the board
* @param[out] pdw_BaseAddress1 : Base address 1 of the board
* @param[out] pb_Interrupt : Interrupt number of the board
* @return    > 0 : Warning \n                                       
*              0 : No Error \n                                      
*             -1 : No device available \n                                    
*             -2 : Wrong device index parameter \n                   
*             -3 : Get the classe device information error \n
*             -4 : Enum Interface error \n
*             -5 :  Memory allocation error \n
*             -6 : Get device interface detail error \n
*             -7 : Open the device error \n
*             -8 : Get device information error \n
*/
_INT_ i_PCI2032_GetBoardInformation(BYTE b_BoardIndex,
			 					    PCHAR pc_Identifier,
			 					    DWORD dw_IdentifierStringSize,
								    PDWORD pdw_UINumber,
								    PDWORD pdw_DeviceNumber,
								    PDWORD pdw_BusNumber,
								    PDWORD pdw_BaseAddress0,
								    PDWORD pdw_BaseAddress1,
								    PBYTE pb_Interrupt);

/** Open the board with the index : b_BoardIndex. A handle is returned to the \n    
* user which allows to use the driver functions. \n                             
*                                                                                  
* @param[in] b_BoardIndex : Index of the board to open                             
* @param[out] ph_DeviceHandle Handle of the selected xPCI-2032 board for using the functions
* @return    > 0 : Warning \n                                                      
*              0 : No Error \n                                                     
*             -1 : Not available board index \n                                    
*             -2 : Board not present \n                                            
*             -3 : No handle is available for the board      */

_INT_ i_PCI2032_OpenBoardViaIndex (BYTE b_BoardIndex,
                                   PHANDLE  ph_DeviceHandle);    

/** Open the board with the indentifier : pc_Identifier. A handle is returned to the \n    
* user which allows to use the following functions. \n                             
* Handles allow to operate several boards.                                         
*                                                                                  
* @param[in] pc_Identifier : Identifier of the board to open                             
* @param[out] ph_DeviceHandle: Handle of the board xPCI-2032 for using the functions
* @return    > 0 : Warning \n                                                      
*              0 : No Error \n                                                     
*             -1 : No device available \n                                    
*             -2 : Wrong indentifier parameter \n                   
*             -3 : Device already opened \n                  
*             -4 : Wrong GUID Class code \n                  
*             -5 : Instance does not exist \n                  
*             -6 : Memory allocation error \n                  
*             -7 : Symbolic link name error \n                  
*             -8 : Create file error \n
*             -9 : Get identifier error \n
*             -10 : no device found with this identifier
*/

_INT_ i_PCI2032_OpenBoardViaIdentifier (PCHAR pc_Identifier,
                                        PHANDLE ph_DeviceHandle);	

/** Releases the handle of the board. Blocks the access to the board.
*                                                                   
* @param[in] h_DeviceHandle    : Handle of the board                
* @return    > 0 : Warning \n                                       
*              0 : No Error \n                                      
*             -1 : The device handle parameter is wrong */

_INT_ i_PCI2032_CloseBoard (HANDLE  h_DeviceHandle);

/*Function's Name   : i_PCI2032_GetDeviceDriverVersion*/
/** Return the version of the device driver.
*                                                                   
* @param[in] h_DeviceHandle  : Handle of the board                
* @param[out] pdw_Version  : Version. sample : 0x01010000 -> version 1.01                 
* @return    > 0 : Warning \n                                       
*              0 : No Error \n                                                     
*             -1 : No device available \n                                    
*             -2 : Wrong device handle parameter       */
_INT_ i_PCI2032_GetDeviceDriverVersion(HANDLE h_DeviceHandle, PDWORD pdw_Version);

/*Function's Name   : i_PCI2032_GetDLLVersion*/
/** Return the version of the DLL.
*                                                                   
* @param[out] pdw_Version  : Version. sample : 0x01010910 -> version 1.01 september 2010                
* @return    > 0 : Warning \n                                       
*              0 : No Error \n                    */
_INT_ i_PCI2032_GetDLLVersion (PDWORD pdw_Version);


/* @} */ 

/** \addtogroup DigO xPCI-2032 digital output functions 
* \ingroup PCI2032
 * @{ 
 * 
 */ 

/*i_PCI2032_SetDigitalOutputMemoryOn*/
/** Activate the digital output memory of the board xPCI-2032               
*                                                                          
* @param[in] h_DeviceHandle      : Handle of the board                      
* @return    > 0 : Warning \n                                              
*              0 : No Error \n                                             
*             -1 : The device handle parameter is wrong \n
*             -2 : Error by activate the digital output memory */           

_INT_ i_PCI2032_SetDigitalOutputMemoryOn (HANDLE h_DeviceHandle);

/*i_PCI2032_SetDigitalOutputMemoryOff*/
/** Deactivate the digital output memory of the board xPCI-2032               
*                                                                          
* @param[in] h_DeviceHandle      : Handle of the board                      
* @return    > 0 : Warning \n                                              
*              0 : No Error \n                                             
*             -1 : The device handle parameter is wrong \n
*             -2 : Error by deactivate the digital output memory */    
_INT_ i_PCI2032_SetDigitalOutputMemoryOff (HANDLE h_DeviceHandle);

/*i_PCI2032_Set1DigitalOutputOn*/
/** Permits to set a digital output of the board xPCI-2032               
*                                                                          
* @param[in] h_DeviceHandle      : Handle of the board                      
* @param[in] b_Channel           : Digital output channel to set (0 to 31)                      
* @return    > 0 : Warning \n                                              
*              0 : No Error \n                                             
*             -1 : The device handle parameter is wrong \n
*             -2 : The channel value is wrong \n                    
*             -3 : Error by the set of the digital output */           
_INT_ i_PCI2032_Set1DigitalOutputOn (HANDLE h_DeviceHandle,BYTE b_Channel);

/*i_PCI2032_Set1DigitalOutputOff*/
/** Permits to reset a digital output of the board xPCI-2032               
*                                                                          
* @param[in] h_DeviceHandle      : Handle of the board                      
* @param[in] b_Channel           : Digital output channel to reset (0 to 31)                      
* @return    > 0 : Warning \n                                              
*              0 : No Error \n                                             
*             -1 : The device handle parameter is wrong \n
*             -2 : The channel value is wrong \n                    
*             -3 : Error by the reset of the digital output */           
_INT_ i_PCI2032_Set1DigitalOutputOff (HANDLE h_DeviceHandle,BYTE b_Channel);



/*i_PCI2032_Set32DigitalOutputsOn*/
/** Permits to set several digital outputs of the board xPCI-2032               
*                                                                          
* @param[in] h_DeviceHandle      : Handle of the board                      
* @param[in] dw_Value            : Digital output mask value to set (0 to 0xFFFFFFFF)                      
* @return    > 0 : Warning \n                                              
*              0 : No Error \n                                             
*             -1 : The device handle parameter is wrong \n
*             -2 : Error by the set of the digital output */           
_INT_ i_PCI2032_Set32DigitalOutputsOn (HANDLE h_DeviceHandle,DWORD dw_Value);

/*i_PCI2032_Set32DigitalOutputsOff*/
/** Permits to reset several digital outputs of the board xPCI-2032               
*                                                                          
* @param[in] h_DeviceHandle      : Handle of the board                      
* @param[in] dw_Value            : Digital output mask value to reset (0 to 0xFFFFFFFF)                      
* @return    > 0 : Warning \n                                              
*              0 : No Error \n                                             
*             -1 : The device handle parameter is wrong \n
*             -3 : Error by the reset of the digital output */           
_INT_ i_PCI2032_Set32DigitalOutputsOff (HANDLE h_DeviceHandle,DWORD dw_Value);



/* @} */ 

/** \addtogroup Watchdog xPCI-2032 watchdog functions 
* \ingroup PCI2032 
 * @{ 
 * 
 */ 

/*i_PCI2032_InitAndStartWatchdog*/
/** Permits to initialise and start the watchdog of the board xPCI-2032               
*                                                                          
* @param[in] h_DeviceHandle     : Handle of the board                      
* @param[in] dw_Value           : Watchodg reload value (20ms to 5100ms, step 20ms)    
* @param[in] b_InterruptFlag    : Interrupt flag (not used -> set to 0)
* @return    > 0 : Warning \n                                              
*              0 : No Error \n                                             
*             -1 : The device handle parameter is wrong \n
*             -2 : The value is wrong \n                    
*             -3 : The interrupt flag is wrong \n                    
*             -4 : Error by the initialisation of the watchdog \n
*             -5 : Error by the start of the watchdog */           
_INT_ i_PCI2032_InitAndStartWatchdog (HANDLE h_DeviceHandle,DWORD dw_Value,BYTE b_InterruptFlag);



/*i_PCI2032_StopAndReleaseWatchdog*/
/** Permits to stop and release the watchdog of the board xPCI-2032               
*                                                                          
* @param[in] h_DeviceHandle     : Handle of the board                      
* @return    > 0 : Warning \n                                              
*              0 : No Error \n                                             
*             -1 : The device handle parameter is wrong \n
*             -2 : Error by the stop of the watchdog */           
_INT_ i_PCI2032_StopAndReleaseWatchdog (HANDLE h_DeviceHandle);


/*i_PCI2032_ReadWatchdogStatus*/
/** Read the status of the watchdog of the board xPCI-2032               
*                                                                          
* @param[in] h_DeviceHandle       : Handle of the board                      
* @param[out] pb_Status           : Watchdog status \n
*                                   0: Watchdog is running \n
*                                   1: Watchdog has run down 
* @return    > 0 : Warning \n                                              
*              0 : No Error \n                                             
*             -1 : The device handle parameter is wrong \n           
*             -2 : Error by reading the status of the watchdog */

_INT_ i_PCI2032_ReadWatchdogStatus (HANDLE h_DeviceHandle,
									PBYTE pb_Status);

/* @} */ 

								

#ifdef __cplusplus
	}
#endif
